UnboundQueue

Struct UnboundQueue 

pub struct UnboundQueue<M: RawMutex = CriticalSectionRawMutex>(/* private fields */);
An unbounded queue implementation using VecDeque from the alloc crate.

Note that this queue does allocate memory on push, and deallocates memory on pop, so it may not be suitable for all use cases (e.g. embedded contexts without an allocator, or contexts where allocations are not allowed in ISRs).

Implementations

Source

impl<M: RawMutex> UnboundQueue<M>

pub const fn new() -> Self

Creates a new empty queue.

pub fn with_capacity(capacity: usize) -> Self

Create a new queue with the specified capacity.