pub struct UnboundQueue<M: RawMutex = CriticalSectionRawMutex>(/* private fields */);Expand description
An unbounded queue implementation using VecDeque from the alloc crate.
Note that this queue does allocate memory on push, and deallocates memory on pop, so it may not be suitable for all use cases (e.g. embedded contexts without an allocator, or contexts where allocations are not allowed in ISRs).
Implementations
Sourceimpl<M: RawMutex> UnboundQueue<M>
impl<M: RawMutex> UnboundQueue<M>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Create a new queue with the specified capacity.